@@ -5,7 +5,6 @@ namespace Icinga\Controllers;
 
 use Exception;
 use Icinga\Application\Config;
-use Icinga\Application\Icinga;
 use Icinga\Exception\NotFoundError;
 use Icinga\Data\DataArray\ArrayDatasource;
 use Icinga\Data\Filter\FilterMatchCaseInsensitive;
@@ -13,6 +12,7 @@ use Icinga\Forms\ConfirmRemovalForm;
 use Icinga\Forms\Navigation\NavigationConfigForm;
 use Icinga\Web\Controller;
 use Icinga\Web\Form;
+use Icinga\Web\Menu;
 use Icinga\Web\Navigation\Navigation;
 use Icinga\Web\Notification;
 use Icinga\Web\Url;
@@ -127,6 +127,7 @@ class NavigationController extends Controller
         $this->view->types = $this->listItemTypes();
         $this->view->items = $query;
 
+        $this->view->title = $this->translate('Navigation');
         $this->getTabs()
         ->add(
             'account',
@@ -144,6 +145,14 @@ class NavigationController extends Controller
                 'label'     => $this->translate('Navigation'),
                 'url'       => 'navigation'
             )
+        )
+        ->add(
+            'devices',
+            array(
+                'title' => $this->translate('List of devices you are logged in'),
+                'label' => $this->translate('My Devices'),
+                'url'   => 'my-devices'
+            )
         );
         $this->setupSortControl(
             array(
@@ -160,12 +169,13 @@ class NavigationController extends Controller
      */
     public function sharedAction()
     {
-        $this->assertPermission('config/application/navigation');
+        $this->assertPermission('config/navigation');
         $ds = new ArrayDatasource($this->fetchSharedNavigationItemConfigs());
         $query = $ds->select();
 
         $removeForm = new Form();
         $removeForm->setUidDisabled();
+        $removeForm->setAttrib('class', 'inline');
         $removeForm->addElement('hidden', 'name', array(
             'decorators'    => array('ViewHelper')
         ));
@@ -187,6 +197,7 @@ class NavigationController extends Controller
         $this->view->types = $this->listItemTypes();
         $this->view->items = $query;
 
+        $this->view->title = $this->translate('Shared Navigation');
         $this->getTabs()->add(
             'navigation/shared',
             array(
@@ -242,6 +253,7 @@ class NavigationController extends Controller
         });
         $form->handleRequest();
 
+        $this->view->title = $this->translate('Navigation');
         $this->renderForm($form, $this->translate('New Navigation Item'));
     }
 
@@ -255,7 +267,7 @@ class NavigationController extends Controller
         $referrer = $this->params->get('referrer', 'index');
 
         $user = $this->Auth()->getUser();
-        if ($user->can('config/application/navigation')) {
+        if ($user->can('config/navigation')) {
             $itemOwner = $this->params->get('owner', $user->getUsername());
         } else {
             $itemOwner = $user->getUsername();
@@ -297,6 +309,7 @@ class NavigationController extends Controller
             $this->httpNotFound(sprintf($this->translate('Navigation item "%s" not found'), $itemName));
         }
 
+        $this->view->title = $this->translate('Navigation');
         $this->renderForm($form, $this->translate('Update Navigation Item'));
     }
 
@@ -340,6 +353,7 @@ class NavigationController extends Controller
         });
         $form->handleRequest();
 
+        $this->view->title = $this->translate('Navigation');
         $this->renderForm($form, $this->translate('Remove Navigation Item'));
     }
 
@@ -348,7 +362,7 @@ class NavigationController extends Controller
      */
     public function unshareAction()
     {
-        $this->assertPermission('config/application/navigation');
+        $this->assertPermission('config/navigation');
         $this->assertHttpMethod('POST');
 
         // TODO: I'd like these being form fields
@@ -419,7 +433,7 @@ class NavigationController extends Controller
             'url'       => Url::fromRequest()
         ));
 
-        $menu = Icinga::app()->getMenu();
+        $menu = new Menu();
 
         $navigation = $menu->findItem($name);
 
@@ -428,5 +442,6 @@ class NavigationController extends Controller
         }
 
         $this->view->navigation = $navigation;
+        $this->view->title = $navigation->getLabel();
     }
 }
