@@ -12,6 +12,13 @@ use Icinga\Web\Response\JsonResponse;
  */
 class Response extends Zend_Controller_Response_Http
 {
+    /**
+     * The default content type being used for responses
+     *
+     * @var string
+     */
+    const DEFAULT_CONTENT_TYPE = 'text/html; charset=UTF-8';
+
     /**
      * Auto-refresh interval
      *
@@ -40,6 +47,13 @@ class Response extends Zend_Controller_Response_Http
      */
     protected $request;
 
+    /**
+     * Whether to instruct the client to reload the window
+     *
+     * @var bool
+     */
+    protected $reloadWindow;
+
     /**
      * Whether to instruct client side script code to reload CSS
      *
@@ -54,6 +68,13 @@ class Response extends Zend_Controller_Response_Http
      */
     protected $rerenderLayout = false;
 
+    /**
+     * Whether to send the current window ID to the client
+     *
+     * @var bool
+     */
+    protected $overrideWindowId = false;
+
     /**
      * Get the auto-refresh interval
      *
@@ -146,6 +167,31 @@ class Response extends Zend_Controller_Response_Http
         return $this;
     }
 
+    /**
+     * Get an array of all header values for the given name
+     *
+     * @param   string  $name       The name of the header
+     * @param   bool    $lastOnly   If this is true, the last value will be returned as a string
+     *
+     * @return  null|array|string
+     */
+    public function getHeader($name, $lastOnly = false)
+    {
+        $result = ($lastOnly ? null : array());
+        $headers = $this->getHeaders();
+        foreach ($headers as $header) {
+            if ($header['name'] === $name) {
+                if ($lastOnly) {
+                    $result = $header['value'];
+                } else {
+                    $result[] = $header['value'];
+                }
+            }
+        }
+
+        return $result;
+    }
+
     /**
      * Get the request
      *
@@ -159,6 +205,30 @@ class Response extends Zend_Controller_Response_Http
         return $this->request;
     }
 
+    /**
+     * Get whether to instruct the client to reload the window
+     *
+     * @return bool
+     */
+    public function isWindowReloaded()
+    {
+        return $this->reloadWindow;
+    }
+
+    /**
+     * Set whether to instruct the client to reload the window
+     *
+     * @param bool $reloadWindow
+     *
+     * @return $this
+     */
+    public function setReloadWindow($reloadWindow)
+    {
+        $this->reloadWindow = $reloadWindow;
+
+        return $this;
+    }
+
     /**
      * Get whether to instruct client side script code to reload CSS
      *
@@ -205,14 +275,39 @@ class Response extends Zend_Controller_Response_Http
         return $this;
     }
 
+    /**
+     * Get whether to send the current window ID to the client
+     *
+     * @return bool
+     */
+    public function getOverrideWindowId()
+    {
+        return $this->overrideWindowId;
+    }
+
+    /**
+     * Set whether to send the current window ID to the client
+     *
+     * @param bool $overrideWindowId
+     *
+     * @return $this
+     */
+    public function setOverrideWindowId($overrideWindowId = true)
+    {
+        $this->overrideWindowId = $overrideWindowId;
+        return $this;
+    }
+
     /**
      * Entry point for HTTP responses in JSON format
      *
      * @return JsonResponse
      */
-    public static function json()
+    public function json()
     {
-        return new JsonResponse();
+        $response = new JsonResponse();
+        $response->copyMetaDataFrom($this);
+        return $response;
     }
 
     /**
@@ -223,25 +318,48 @@ class Response extends Zend_Controller_Response_Http
         $redirectUrl = $this->getRedirectUrl();
         if ($this->getRequest()->isXmlHttpRequest()) {
             if ($redirectUrl !== null) {
+                if ($this->getRequest()->isGet() && Icinga::app()->getViewRenderer()->view->compact) {
+                    $redirectUrl->getParams()->set('showCompact', true);
+                }
+
                 $this->setHeader('X-Icinga-Redirect', rawurlencode($redirectUrl->getAbsoluteUrl()), true);
                 if ($this->getRerenderLayout()) {
                     $this->setHeader('X-Icinga-Rerender-Layout', 'yes', true);
                 }
             }
+            if ($this->getOverrideWindowId()) {
+                $this->setHeader('X-Icinga-WindowId', Window::getInstance()->getId(), true);
+            }
             if ($this->getRerenderLayout()) {
                 $this->setHeader('X-Icinga-Container', 'layout', true);
             }
+            if ($this->isWindowReloaded()) {
+                $this->setHeader('X-Icinga-Reload-Window', 'yes', true);
+            }
             if ($this->isReloadCss()) {
                 $this->setHeader('X-Icinga-Reload-Css', 'now', true);
             }
             if (($autoRefreshInterval = $this->getAutoRefreshInterval()) !== null) {
                 $this->setHeader('X-Icinga-Refresh', $autoRefreshInterval, true);
             }
+
+            $notifications = Notification::getInstance();
+            if ($notifications->hasMessages()) {
+                $notificationList = array();
+                foreach ($notifications->popMessages() as $m) {
+                    $notificationList[] = rawurlencode($m->type . ' ' . $m->message);
+                }
+                $this->setHeader('X-Icinga-Notification', implode('&', $notificationList), true);
+            }
         } else {
             if ($redirectUrl !== null) {
                 $this->setRedirect($redirectUrl->getAbsoluteUrl());
             }
         }
+
+        if (! $this->getHeader('Content-Type', true)) {
+            $this->setHeader('Content-Type', static::DEFAULT_CONTENT_TYPE);
+        }
     }
 
     /**
@@ -271,12 +389,12 @@ class Response extends Zend_Controller_Response_Http
             /** @var Cookie $cookie */
             setcookie(
                 $cookie->getName(),
-                $cookie->getValue(),
-                $cookie->getExpire(),
+                $cookie->getValue() ?? '',
+                $cookie->getExpire() ?? 0,
                 $cookie->getPath(),
-                $cookie->getDomain(),
+                $cookie->getDomain() ?? '',
                 $cookie->isSecure(),
-                $cookie->isHttpOnly()
+                $cookie->isHttpOnly() ?? true
             );
         }
     }
@@ -292,4 +410,20 @@ class Response extends Zend_Controller_Response_Http
         }
         return parent::sendHeaders();
     }
+
+    /**
+     * Copies non-body-related response data from $response
+     *
+     * @param   Response    $response
+     *
+     * @return  $this
+     */
+    protected function copyMetaDataFrom(self $response)
+    {
+        $this->_headers = $response->_headers;
+        $this->_headersRaw = $response->_headersRaw;
+        $this->_httpResponseCode = $response->_httpResponseCode;
+        $this->headersSentThrowsException = $response->headersSentThrowsException;
+        return $this;
+    }
 }
