@@ -166,8 +166,8 @@ class Url
 
         if (! is_string($url)) {
             throw new ProgrammingError(
-                'url "%s" is not a string',
-                $url
+                'url %s is not a string',
+                var_export($url, true)
             );
         }
 
@@ -367,75 +367,6 @@ class Url
         return $this->scheme;
     }
 
-    /**
-     * Set the baseUrl for this url
-     *
-     * @deprecated  Please create a new url from scratch instead
-     *
-     * @param       string  $baseUrl    The url path to use as the url base
-     *
-     * @return      $this
-     */
-    public function setBaseUrl($baseUrl)
-    {
-        $urlParts = parse_url($baseUrl);
-        if (isset($urlParts["host"])) {
-            $this->setHost($urlParts["host"]);
-        }
-        if (isset($urlParts["port"])) {
-            $this->setPort($urlParts["port"]);
-        }
-        if (isset($urlParts['scheme'])) {
-            $this->setScheme($urlParts['scheme']);
-        }
-        if (isset($urlParts['user'])) {
-            $this->setUsername($urlParts['user']);
-        }
-        if (isset($urlParts['pass'])) {
-            $this->setPassword($urlParts['pass']);
-        }
-        if (isset($urlParts['path'])) {
-            $this->setBasePath($urlParts['path']);
-        }
-
-        return $this;
-    }
-
-    /**
-     * Return the baseUrl for this url
-     *
-     * @deprecated
-     *
-     * @return  string
-     */
-    public function getBaseUrl()
-    {
-        if (! $this->isExternal()) {
-            return $this->getBasePath();
-        }
-
-        $urlString = '';
-        if ($this->getScheme()) {
-            $urlString .= $this->getScheme() . '://';
-        }
-        if ($this->getPassword()) {
-            $urlString .= $this->getUsername() . ':' . $this->getPassword() . '@';
-        } elseif ($this->getUsername()) {
-            $urlString .= $this->getUsername() . '@';
-        }
-        if ($this->getHost()) {
-            $urlString .= $this->getHost();
-        }
-        if ($this->getPort()) {
-            $urlString .= ':' . $this->getPort();
-        }
-        if ($this->getBasePath()) {
-            $urlString .= $this->getBasePath();
-        }
-
-        return $urlString;
-    }
-
     /**
      * Set the relative path of this url, without query parameters
      *
@@ -845,9 +776,13 @@ class Url
         }
 
         $url = clone $this;
-        foreach ($url->getParams()->toArray(false) as $key => $_) {
-            if (! in_array($key, $keyOrArrayOfKeys, true)) {
-                $url->remove($key);
+        foreach ($url->getParams()->toArray(false) as $param => $value) {
+            if (is_int($param)) {
+                $param = $value;
+            }
+
+            if (! in_array($param, $keyOrArrayOfKeys, true)) {
+                $url->remove($param);
             }
         }
 
@@ -866,6 +801,6 @@ class Url
      */
     public function __toString()
     {
-        return $this->getAbsoluteUrl('&amp;');
+        return htmlspecialchars($this->getAbsoluteUrl(), ENT_COMPAT | ENT_SUBSTITUTE | ENT_HTML5, 'UTF-8', true);
     }
 }
