@@ -274,7 +274,7 @@ class FilterEditor extends AbstractWidget
                         $filter = Filter::matchAll();
                     }
                     $filters = array();
-                    $search = ltrim($search);
+                    $search = trim($search);
                     foreach ($this->searchColumns as $searchColumn) {
                         $filters[] = Filter::expression($searchColumn, '=', "*$search*");
                     }
@@ -285,12 +285,13 @@ class FilterEditor extends AbstractWidget
                 }
             }
 
-            $url = $this->url()->setQueryString(
-                $filter->toQueryString()
-            )->addParams($preserve);
-            if ($modify) {
-                $url->getParams()->add('modifyFilter');
+            $url = Url::fromRequest()->onlyWith($this->preserveParams);
+            $urlParams = $url->getParams();
+            $url->setQueryString($filter->toQueryString());
+            foreach ($urlParams->toArray(false) as $key => $value) {
+                $url->getParams()->addEncoded($key, $value);
             }
+
             $this->redirectNow($url);
         }
 
