@@ -40,6 +40,13 @@ class EventController extends Controller
         'dt_end'                => 'downtimeevent'
     );
 
+    public function init()
+    {
+        if (Hook::has('ticket')) {
+            $this->view->tickets = Hook::first('ticket');
+        }
+    }
+
     public function showAction()
     {
         $type = $this->params->shiftRequired('type');
@@ -76,7 +83,7 @@ class EventController extends Controller
         /** @var EventDetailsExtensionHook $hook */
         foreach (Hook::all('Monitoring\\EventDetailsExtension') as $hook) {
             try {
-                $html = $hook->getHtmlForEvent($object);
+                $html = $hook->getHtmlForEvent($event);
             } catch (\Exception $e) {
                 $html = $this->view->escape($e->getMessage());
             }
