@@ -783,6 +783,30 @@ abstract class IdoQuery extends DbQuery
         return parent::where($col, $value);
     }
 
+    /**
+     * Add a filter expression, with as less validation as possible
+     *
+     * @param FilterExpression $ex
+     *
+     * @internal If you use this outside the monitoring module, it's your fault if something breaks
+     * @return $this
+     */
+    public function whereEx(FilterExpression $ex)
+    {
+        $this->requireColumn($ex->getColumn());
+        $col = $this->getMappedField($ex->getColumn());
+        if ($col === null) {
+            throw new IcingaException(
+                'No such field: %s',
+                $ex->getColumn()
+            );
+        }
+
+        parent::addFilter((clone $ex)->setColumn($col));
+
+        return $this;
+    }
+
     /**
      * Return true if an field contains an explicit timestamp
      *
@@ -874,6 +898,10 @@ abstract class IdoQuery extends DbQuery
             '%1$s = %2$s.object_id AND LOWER(%2$s.varname) = %3$s';
         foreach ($this->columnMap as $table => & $columns) {
             foreach ($columns as $alias => & $column) {
+                if ($column === null) {
+                    continue;
+                }
+
                 // Using a regex here because COLLATE may occur anywhere in the string
                 $column = preg_replace('/ COLLATE .+$/', '', $column, -1, $count);
                 if ($count > 0) {
@@ -1021,7 +1049,7 @@ abstract class IdoQuery extends DbQuery
      *
      * This calls requireVirtualTable if needed
      *
-     * @param $alias                                The alias of the column to require
+     * @param string $alias                          The alias of the column to require
      *
      * @return $this                                 Fluent interface
      * @see    IdoQuery::requireVirtualTable        The method initializing required joins
