@@ -3,23 +3,24 @@
 
 namespace Icinga\Module\Monitoring\Backend\Ido\Query;
 
+use Icinga\Data\Filter\Filter;
+use Icinga\Data\Filter\FilterExpression;
+
 /**
  * Query for host downtime end history records
  */
 class ServicedowntimeendhistoryQuery extends ServicedowntimestarthistoryQuery
 {
-    /**
-     * {@inheritdoc}
-     */
-    public function whereToSql($col, $sign, $expression)
+    protected function requireFilterColumns(Filter $filter)
     {
-        if ($col === 'UNIX_TIMESTAMP(sdh.actual_end_time)') {
-            return 'sdh.actual_end_time ' . $sign . ' ' . $this->timestampForSql(
-                $this->valueToTimestamp($expression)
-            );
-        } else {
-            return parent::whereToSql($col, $sign, $expression);
+        if ($filter instanceof FilterExpression && $filter->getColumn() === 'timestamp') {
+            $this->requireColumn('timestamp');
+            $filter->setColumn('sdh.actual_end_time');
+            $filter->setExpression($this->timestampForSql($this->valueToTimestamp($filter->getExpression())));
+            return null;
         }
+
+        return parent::requireFilterColumns($filter);
     }
 
     /**
